@@ -287,6 +287,7 @@ class Page(Base):
         immediately to the client.
         """
         request._feincms_page = self
+        request._feincms_extra_context = {}
 
         for fn in self.request_processors:
             r = fn(self, request)
@@ -361,7 +362,7 @@ class Page(Base):
     def debug_sql_queries_response_processor(self, request, response):
         if django_settings.DEBUG:
             from django.db import connection
-            
+
             print_sql = lambda x: x
             try:
                 import sqlparse
@@ -381,7 +382,7 @@ class Page(Base):
             print "Total: %d queries, %f ms" % (i, time)
             print "--------------------------------------------------------------"
 
-        
+
     @classmethod
     def register_request_processors(cls, *processors):
         cls.request_processors[0:0] = processors
@@ -425,7 +426,8 @@ class PageAdminForm(forms.ModelForm):
                     data = model_to_dict(page)
 
                     for field in PageManager.exclude_from_copy:
-                        del data[field]
+                        if field in data:
+                            del data[field]
 
                     # These are always excluded from prefilling
                     for field in ('title', 'slug', 'parent', 'active'):
